@@ -20,9 +20,9 @@
 #include <libmnl/libmnl.h>
 #include <libnftnl/chain.h>
 
-static struct nft_chain *chain_add_parse(int argc, char *argv[])
+static struct nftnl_chain *chain_add_parse(int argc, char *argv[])
 {
-	struct nft_chain *t;
+	struct nftnl_chain *t;
 	int hooknum = 0;
 
 	if (argc == 6) {
@@ -43,16 +43,16 @@ static struct nft_chain *chain_add_parse(int argc, char *argv[])
 		}
 	}
 
-	t = nft_chain_alloc();
+	t = nftnl_chain_alloc();
 	if (t == NULL) {
 		perror("OOM");
 		return NULL;
 	}
-	nft_chain_attr_set(t, NFT_CHAIN_ATTR_TABLE, argv[2]);
-	nft_chain_attr_set(t, NFT_CHAIN_ATTR_NAME, argv[3]);
+	nftnl_chain_set(t, NFTNL_CHAIN_TABLE, argv[2]);
+	nftnl_chain_set(t, NFTNL_CHAIN_NAME, argv[3]);
 	if (argc == 6) {
-		nft_chain_attr_set_u32(t, NFT_CHAIN_ATTR_HOOKNUM, hooknum);
-		nft_chain_attr_set_u32(t, NFT_CHAIN_ATTR_PRIO, atoi(argv[5]));
+		nftnl_chain_set_u32(t, NFTNL_CHAIN_HOOKNUM, hooknum);
+		nftnl_chain_set_u32(t, NFTNL_CHAIN_PRIO, atoi(argv[5]));
 	}
 
 	return t;
@@ -65,7 +65,7 @@ int main(int argc, char *argv[])
 	struct nlmsghdr *nlh;
 	uint32_t portid, seq, chain_seq;
 	int ret, family;
-	struct nft_chain *t;
+	struct nftnl_chain *t;
 	struct mnl_nlmsg_batch *batch;
 	int batching;
 
@@ -93,7 +93,7 @@ int main(int argc, char *argv[])
 	if (t == NULL)
 		exit(EXIT_FAILURE);
 
-	batching = nft_batch_is_supported();
+	batching = nftnl_batch_is_supported();
 	if (batching < 0) {
 		perror("cannot talk to nfnetlink");
 		exit(EXIT_FAILURE);
@@ -103,20 +103,20 @@ int main(int argc, char *argv[])
 	batch = mnl_nlmsg_batch_start(buf, sizeof(buf));
 
 	if (batching) {
-		nft_batch_begin(mnl_nlmsg_batch_current(batch), seq++);
+		nftnl_batch_begin(mnl_nlmsg_batch_current(batch), seq++);
 		mnl_nlmsg_batch_next(batch);
 	}
 
 	chain_seq = seq;
-	nlh = nft_chain_nlmsg_build_hdr(mnl_nlmsg_batch_current(batch),
+	nlh = nftnl_chain_nlmsg_build_hdr(mnl_nlmsg_batch_current(batch),
 					NFT_MSG_NEWCHAIN, family,
-					NLM_F_ACK, seq++);
-	nft_chain_nlmsg_build_payload(nlh, t);
-	nft_chain_free(t);
+					NLM_F_CREATE|NLM_F_ACK, seq++);
+	nftnl_chain_nlmsg_build_payload(nlh, t);
+	nftnl_chain_free(t);
 	mnl_nlmsg_batch_next(batch);
 
 	if (batching) {
-		nft_batch_end(mnl_nlmsg_batch_current(batch), seq++);
+		nftnl_batch_end(mnl_nlmsg_batch_current(batch), seq++);
 		mnl_nlmsg_batch_next(batch);
 	}
 
@@ -138,6 +138,8 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
+	mnl_nlmsg_batch_stop(batch);
+
 	ret = mnl_socket_recvfrom(nl, buf, sizeof(buf));
 	while (ret > 0) {
 		ret = mnl_cb_run(buf, ret, chain_seq, portid, NULL, NULL);
