@@ -71,8 +71,8 @@ int main(int argc, char *argv[])
 	char buf[4096];
 	struct nftnl_expr_iter *iter_a, *iter_b;
 	struct nftnl_expr *rule_a, *rule_b;
-	char *chain = "tests_chain01234";
-	char *data = "test_data_01234";
+	const char *chain = "tests_chain01234";
+	const char *data = "test_data_01234";
 
 	a = nftnl_rule_alloc();
 	b = nftnl_rule_alloc();
